@@ -14,7 +14,7 @@
 #endif
 
 #ifndef link_public_api
-# ifdef _MSC_VER
+# if defined(_MSC_VER) && !defined(LINK_GRAMMAR_STATIC)
 #  if !defined LINK_GRAMMAR_DLL_EXPORT
 #   error !defined LINK_GRAMMAR_DLL_EXPORT
 #  endif
@@ -29,9 +29,9 @@
 #endif
 
 #define LINK_MAJOR_VERSION 5
-#define LINK_MINOR_VERSION 2
-#define LINK_MICRO_VERSION 1
+#define LINK_MINOR_VERSION 4
+#define LINK_MICRO_VERSION 4
 
-#define LINK_VERSION_STRING "5.2.1"
+#define LINK_VERSION_STRING "5.4.4"
 
 #endif
